@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #ifndef _SECURITY_CAITSITH_INTERNAL_H
@@ -90,6 +90,10 @@
 #define current_fsgid() (current->fsgid)
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 16, 0)
+#define d_inode(dentry) (dentry)->d_inode
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 38)
 
 /**
@@ -902,6 +906,10 @@ int cs_mknod_permission(const struct path *path, const unsigned int mode,
 int cs_mount_permission(const char *dev_name, const struct path *path,
 			const char *type, unsigned long flags,
 			void *data_page);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+int cs_move_mount_permission(const struct path *from_path,
+			     const struct path *to_path);
+#endif
 int cs_pivot_root_permission(const struct path *old_path,
 			     const struct path *new_path);
 int cs_rename_permission(const struct path *old, const struct path *new);
