@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #ifndef _SECURITY_CAITSITH_INTERNAL_H
@@ -91,6 +91,10 @@
 #define current_fsgid() (current->fsgid)
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 16, 0)
+#define d_inode(dentry) (dentry)->d_inode
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 38)
 
 /**
