@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #include "caitsith.h"
@@ -829,7 +829,11 @@ bool cs_dump_page(struct linux_binprm *bprm, unsigned long pos,
 	}
 	/* Same with put_arg_page(page) in fs/exec.c */
 #ifdef CONFIG_MMU
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+	put_user_page(page);
+#else
 	put_page(page);
+#endif
 #endif
 	return true;
 }
@@ -1123,6 +1127,22 @@ int cs_mount_permission(const char *dev_name, const struct path *path,
 	return cs_mount_acl(dev_name, path, type, flags, data_page);
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+/**
+ * cs_move_mount_permission - Check permission for move_mount() operation.
+ *
+ * @from_path: Pointer to "struct path".
+ * @to_path:   Pointer to "struct path".
+ *
+ * Returns 0 on success, negative value otherwise.
+ */
+int cs_move_mount_permission(const struct path *from_path,
+			     const struct path *to_path)
+{
+	return -ENOSYS; /* For now. */
+}
+#endif
+
 /**
  * cs_open_permission - Check permission for "read" and "write".
  *
@@ -1150,6 +1170,9 @@ int cs_open_permission(const struct path *path, const int flag)
 	if (d_is_dir(path->dentry))
 		return 0;
 #endif
+	/* Sockets can't be opened by open(). */
+	if (S_ISSOCK(d_inode(path->dentry)->i_mode))
+		return 0;
 	r.obj.path[0] = *path;
 	if (!(cs_flags & CS_TASK_IS_IN_EXECVE))
 		cs_check_auto_domain_transition();
@@ -1507,6 +1530,9 @@ int cs_unlink_permission(const struct path *path)
  */
 int cs_getattr_permission(const struct path *path)
 {
+	/* It is not safe to call cs_get_socket_name(). */
+	if (S_ISSOCK(d_inode(path->dentry)->i_mode))
+		return 0;
 	return cs_path_perm(CS_MAC_GETATTR, path);
 }
 
@@ -1643,6 +1669,8 @@ static int cs_check_inet_address(const struct sockaddr *addr,
 {
 	struct cs_inet_addr_info *i = &address->inet;
 
+	if (addr_len < sizeof(addr->sa_family))
+		goto skip;
 	switch (addr->sa_family) {
 	case AF_INET6:
 		if (addr_len < SIN6_LEN_RFC2133)
@@ -1720,6 +1748,8 @@ static int cs_check_unix_address(struct sockaddr *addr,
 {
 	struct cs_unix_addr_info *u = &address->unix0;
 
+	if (addr_len < sizeof(addr->sa_family))
+		return 0;
 	if (addr->sa_family != AF_UNIX)
 		return 0;
 	u->addr = ((struct sockaddr_un *) addr)->sun_path;
@@ -2917,7 +2947,11 @@ static void cs_check_auto_domain_transition(void)
 		goto done;
 	printk(KERN_WARNING "ERROR: Unable to transit to '%s' domain.\n",
 	       r.transition->name);
+#if LINUX_VERSION_CODE < KERNEL_VERSION(5, 3, 0)
 	force_sig(SIGKILL, current);
+#else
+	force_sig(SIGKILL);
+#endif
 done:
 	cs_read_unlock(idx);
 #endif
