@@ -3,10 +3,11 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #include "caitsith.h"
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36) && LINUX_VERSION_CODE < KERNEL_VERSION(3, 2, 0)
 #include <linux/nsproxy.h>
 #include <linux/mnt_namespace.h>
@@ -462,12 +463,14 @@ char *cs_realpath(const struct path *path)
 		}
 		inode = d_backing_inode(sb->s_root);
 		/*
-		 * Use local name for "filesystems without rename() operation"
-		 * or "path without vfsmount" or "absolute name is unavailable"
-		 * cases.
+		 * Use local name for "filesystems without rename() operation
+		 * and device file" or "path without vfsmount" or "absolute
+		 * name is unavailable" cases.
 		 */
 #if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
-		if (!path->mnt || (inode->i_op && !inode->i_op->rename))
+		if (!path->mnt ||
+		    (inode->i_op && !inode->i_op->rename &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ERR_PTR(-EINVAL);
 		else {
 			/* Get absolute name for the rest. */
@@ -477,12 +480,15 @@ char *cs_realpath(const struct path *path)
 		}
 #elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 9, 0)
 		if (!path->mnt ||
-		    (!inode->i_op->rename && !inode->i_op->rename2))
+		    (!inode->i_op->rename && !inode->i_op->rename2 &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ERR_PTR(-EINVAL);
 		else
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
 #else
-		if (!path->mnt || !inode->i_op->rename)
+		if (!path->mnt ||
+		    (!inode->i_op->rename &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ERR_PTR(-EINVAL);
 		else
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
